@@ -8,7 +8,7 @@ equivalent to non conflict files laying beside them), some of them really
 differs from their neighborhoods. The aim of this script is to resolve
 conflict files of both types. """
 
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 
 # pylint: disable=C0103, C0111, W0105, W0141, W0142
 
@@ -24,6 +24,7 @@ import string
 import subprocess
 import tarfile
 from pathlib import Path
+from collections import defaultdict
 try:
     from enum import IntEnum
 except ImportError:
@@ -44,6 +45,7 @@ class Keep(IntEnum):
 
 
 programs = {
+    None: defaultdict(lambda: defaultdict(str)),
     'merge': {
         'kdiff3': {
             'arguments': '-m $conflict $normal -o $normal',
@@ -388,7 +390,7 @@ class MergeConflictResolver(ConflictResolver):
 
 
 class ListConflictResolver(ConflictResolver):
-    resolving_type = 'none'
+    resolving_type = None
 
     def __init__(self, root=Path('.'), *, list_normal=False, **kwargs):
         super().__init__(root, **kwargs)
@@ -530,11 +532,12 @@ def parse_arguments():
         result.renamer = Renamer
     else:
         result.renamer = LogRenamer
-    result.program = (
-        programs[result.conflict_resolver.resolving_type][result.program_name])
+    result.program = (programs[result.conflict_resolver.resolving_type]
+                      [result.program_name])
     result.program['name'] = result.program_name
-    slr_arguments = (result.program_arguments if result.program_arguments else
-                     result.program['arguments'])
+    slr_arguments = (result.program_arguments
+                        if result.program_arguments else
+                        result.program['arguments'])
     result.program['arguments'] = [
         string.Template(arg) for arg in shlex.split(slr_arguments)]
     return result
